@@ -7,7 +7,7 @@ use Math ();
 
 #use Exporter;
 
-our $VERSION = '0.325';
+our $VERSION = '0.329';
 
 use base 'Math::Vector';
 
@@ -25,6 +25,8 @@ L<Math::Vec3>
 
 =head1 SEE ALSO
 
+L<PDL>
+
 L<Math>
 
 L<Math::Color>, L<Math::ColorRGBA>, L<Math::Image>, L<Math::Vec2>, L<Math::Vec3>, L<Math::Vec4> L<Math::Rotation>
@@ -256,6 +258,8 @@ sub getW { $_[0]->[3] }
 
 =head2 negate
 
+This is used to overload the 'neg' operator.
+
 	$v = $v1->negate;
 	$v = -$v1;
 
@@ -273,6 +277,8 @@ sub negate {
 
 =head2 add(Vec4)
 
+This is used to overload the '+' operator.
+
 	$v = $v1->add($v2);
 	$v = $v1 + $v2;
 	$v = [8, 2, 4] + $v1;
@@ -301,6 +307,8 @@ sub _add {
 
 =head2 subtract(Vec4)
 
+This is used to overload the '-' operator.
+
 	$v = $v1->subtract($v2);
 	$v = $v1 - $v2;
 	$v = [8, 2, 4] - $v1;
@@ -497,6 +505,8 @@ sub __pow {
 
 =head2 dot(Vec4)
 
+This is used to overload the '.' operator.
+
 	$s = $v1->dot($v2);
 	$s = $v1 . $v2;
 	$s = $v1 . [ 2, 3, 4 ];
@@ -516,6 +526,8 @@ sub dot {
 
 =head2 cross(Vec4)
 
+This is used to overload the 'x' operator.
+
 	$v = $v1->cross($v2);
 	$v = $v1 x $v2;
 	$v = $v1 x [ 2, 3, 4 ];
@@ -553,6 +565,7 @@ sub _cross {
 =head2 length
 
 Returns the length of the vector
+This is used to overload the '0+' operator.
 
 	$l = $v1->length;
 
